Mesa (master): mesa: fix snprintf() typo

Brian Paul brianp at kemper.freedesktop.org
Fri Feb 19 20:44:48 UTC 2010


Module: Mesa
Branch: master
Commit: 150cce6aef85d22b5d32fba5d27605a98be6794a
URL:    http://cgit.freedesktop.org/mesa/mesa/commit/?id=150cce6aef85d22b5d32fba5d27605a98be6794a

Author: Brian Paul <brianp at vmware.com>
Date:   Fri Feb 19 13:44:12 2010 -0700

mesa: fix snprintf() typo

---

 src/mesa/shader/program_parse.tab.c |    6 +++---
 src/mesa/shader/program_parse.y     |    2 +-
 2 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/src/mesa/shader/program_parse.y b/src/mesa/shader/program_parse.y
index 75cb4cf..d5fb0fa 100644
--- a/src/mesa/shader/program_parse.y
+++ b/src/mesa/shader/program_parse.y
@@ -2609,7 +2609,7 @@ make_error_string(const char *fmt, ...)
 
    str = malloc(length);
    if (str) {
-      v_mesa_snprintf(str, length, fmt, args);
+      vsnprintf(str, length, fmt, args);
    }
 
    va_end(args);




More information about the mesa-commit mailing list
diff --git a/src/mesa/shader/program_parse.tab.c b/src/mesa/shader/program_parse.tab.c
index 52f6084..5679b64 100644
--- a/src/mesa/shader/program_parse.tab.c
+++ b/src/mesa/shader/program_parse.tab.c
@@ -5559,18 +5559,18 @@ make_error_string(const char *fmt, ...)
 
    va_start(args, fmt);
 
    /* Call v_mesa_snprintf once to determine how large the final string is.  Call it
     * again to do the actual formatting.  from the v_mesa_snprintf manual page:
     *
     *    Upon successful return, these functions return the number of
     *    characters printed  (not including the trailing '\0' used to end
     *    output to strings).
     */
-   length = 1 + v_mesa_snprintf(NULL, 0, fmt, args);
+   length = 1 + vsnprintf(NULL, 0, fmt, args);
 
    str = malloc(length);
    if (str) {
-      v_mesa_snprintf(str, length, fmt, args);
+      vsnprintf(str, length, fmt, args);
    }
 
    va_end(args);
@@ -5559,18 +5559,18 @@ make_error_string(const char *fmt, ...)
    va_start(args, fmt);
 
-   /* Call v_mesa_snprintf once to determine how large the final string is.  Call it
+   /* Call vsnprintf once to determine how large the final string is.  Call it
     * again to do the actual formatting.  from the v_mesa_snprintf manual page:
     *